@@ -47,15 +47,12 @@ AH_JOB *AH_Job_GetTransactions_new(AB_USER *u,
   AH_JOB *j;
   AH_JOB_GETTRANSACTIONS *aj;
   GWEN_DB_NODE *dbArgs;
+  GWEN_DB_NODE *updgroup;
 
   int useCreditCardJob = 0;
 
   //Check if we should use DKKKU
-  GWEN_DB_NODE *updgroup;
-  updgroup=AH_User_GetUpd(u);
-  assert(updgroup);
-  updgroup=GWEN_DB_GetGroup(updgroup, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-                            AB_Account_GetAccountNumber(account));
+  updgroup=AH_User_GetUpdForAccount(u, account);
   if (updgroup) {
      GWEN_DB_NODE *n;
       n=GWEN_DB_GetFirstGroup(updgroup);
@@ -211,9 +208,42 @@ int AH_Job_GetTransactions__ReadTransactions(AH_JOB *j,
         GWEN_DB_Dump(dbT, 2);
       }
       else {
+	const char *s;
+
         AB_Transaction_SetLocalBankCode(t, AB_User_GetBankCode(u));
         AB_Transaction_SetLocalAccountNumber(t,
                                              AB_Account_GetAccountNumber(a));
+
+	/* some translations */
+	s=AB_Transaction_GetRemoteIban(t);
+	if (!(s && *s)) {
+	  const char *sAid;
+
+	  /* no remote IBAN set, check whether the bank sends this info in the
+	   * fields for national account specifications (instead of the SWIFT
+	   * field "?38" which was specified for this case) */
+	  sAid=AB_Transaction_GetRemoteAccountNumber(t);
+	  if (sAid && *sAid && AB_Banking_CheckIban(sAid)==0) {
+	    /* there is a remote account number specification, and that is an IBAN,
+	     * so we set that accordingly */
+	    DBG_INFO(AQBANKING_LOGDOMAIN, "Setting remote IBAN from account number");
+	    AB_Transaction_SetRemoteIban(t, sAid);
+
+	    /* set remote BIC if it not already is */
+	    s=AB_Transaction_GetRemoteBic(t);
+	    if (!(s && *s)) {
+	      const char *sBid;
+
+	      sBid=AB_Transaction_GetRemoteBankCode(t);
+	      if (sBid && *sBid) {
+		DBG_INFO(AQBANKING_LOGDOMAIN, "Setting remote BIC from bank code");
+		AB_Transaction_SetRemoteBic(t, sBid);
+	      }
+	    }
+	  }
+	}
+
+
         DBG_INFO(AQHBCI_LOGDOMAIN, "Adding transaction");
         if (noted)
 	  AB_ImExporterAccountInfo_AddNotedTransaction(ai, t);
@@ -476,6 +506,8 @@ int AH_Job_GetTransactionsCreditCard_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *c
       GWEN_TIME *date;
       GWEN_TIME *valutaDate;
       const char *p;
+      const char *ref;
+      int i;
 
       dbT=GWEN_DB_GetGroup(dbXA, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
                            "entries");
@@ -530,18 +562,22 @@ int AH_Job_GetTransactionsCreditCard_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *c
         }
 
         /* read purpose */
-        p=GWEN_DB_GetCharValue(dbT, "purpose", 0, 0);
-        if (p)
-          purpose=GWEN_StringList_fromTabString(p, 0);
-        else
-          purpose=NULL;
+        purpose=GWEN_StringList_new();
+        for (i=0; i<10; i++) {
+            p=GWEN_DB_GetCharValue(dbT, "purpose", i, 0);
+            if (!p)
+                break;
+            GWEN_StringList_AppendString(purpose, p, 0, 0);
+        }
 
         /* read reference */
-        p=GWEN_DB_GetCharValue(dbT, "reference", 0, 0);
-        if (p)
-          GWEN_StringList_AppendString(purpose, p, 0, 0);
+        ref=GWEN_DB_GetCharValue(dbT, "reference", 0, 0);
+        if (ref)
+          GWEN_StringList_AppendString(purpose, ref, 0, 0);
 
         t=AB_Transaction_new();
+        if(ref)
+            AB_Transaction_SetFiId(t, ref);
         AB_Transaction_SetLocalBankCode(t, AB_User_GetBankCode(u));
         AB_Transaction_SetLocalAccountNumber(t, AB_Account_GetAccountNumber(a));
         AB_Transaction_SetValutaDate(t, valutaDate);
